@@ -105,6 +105,16 @@ class LoadBalancersController(base.BaseController):
             raise exceptions.LBPendingStateError(
                 state=prov_status, id=id)
 
+    def _test_and_set_failover_prov_status(self, session, id):
+        lb_repo = self.repositories.load_balancer
+        if not lb_repo.set_status_for_failover(session, id,
+                                               constants.PENDING_UPDATE):
+            prov_status = lb_repo.get(session, id=id).provisioning_status
+            LOG.info("Invalid state %(state)s of loadbalancer resource %(id)s",
+                     {"state": prov_status, "id": id})
+            raise exceptions.LBPendingStateError(
+                state=prov_status, id=id)
+
     @staticmethod
     def _validate_network_and_fill_or_validate_subnet(load_balancer):
         network = validate.network_exists_optionally_contains_subnet(
@@ -372,7 +382,7 @@ class LoadBalancersController(base.BaseController):
                 pool_name = (
                     redirect_pool.get('name') if redirect_pool else None)
                 # All pools need to have a name so they can be referenced
-                if default_pool and not pool_name:
+                if redirect_pool and not pool_name:
                     raise exceptions.ValidationException(
                         detail='Pools must be named when creating a fully '
                                'populated loadbalancer.')
@@ -383,7 +393,7 @@ class LoadBalancersController(base.BaseController):
                     policy['redirect_pool'] = {'name': pool_name}
                     pools.append(redirect_pool)
                 # Otherwise, it's a reference and we record it and move on
-                elif default_pool:
+                elif redirect_pool:
                     pools_required.add(pool_name)
 
         # Make sure all pool names are unique.
@@ -462,11 +472,12 @@ class LoadBalancersController(base.BaseController):
         self._auth_validate_action(context, db_lb.project_id,
                                    constants.RBAC_PUT)
 
-        if (load_balancer.vip_qos_policy_id and
-                not isinstance(load_balancer.vip_qos_policy_id,
-                               wtypes.UnsetType) and
-                db_lb.vip.qos_policy_id != load_balancer.vip_qos_policy_id):
-            validate.qos_policy_exists(load_balancer.vip_qos_policy_id)
+        if not isinstance(load_balancer.vip_qos_policy_id, wtypes.UnsetType):
+            network_driver = utils.get_network_driver()
+            validate.qos_extension_enabled(network_driver)
+            if load_balancer.vip_qos_policy_id is not None:
+                if db_lb.vip.qos_policy_id != load_balancer.vip_qos_policy_id:
+                    validate.qos_policy_exists(load_balancer.vip_qos_policy_id)
 
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(db_lb.provider)
@@ -644,7 +655,7 @@ class FailoverController(LoadBalancersController):
         driver = driver_factory.get_driver(db_lb.provider)
 
         with db_api.get_lock_session() as lock_session:
-            self._test_lb_status(lock_session, self.lb_id)
+            self._test_and_set_failover_prov_status(lock_session, self.lb_id)
             LOG.info("Sending failover request for load balancer %s to the "
                      "provider %s", self.lb_id, driver.name)
             driver_utils.call_provider(
