@@ -13,15 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
+from oslo_log import log as logging
 from oslo_utils import excutils
 import pecan
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
+from octavia.api.drivers import data_models as driver_dm
+from octavia.api.drivers import driver_factory
+from octavia.api.drivers import utils as driver_utils
 from octavia.api.v2.controllers import base
 from octavia.api.v2.controllers import health_monitor
 from octavia.api.v2.controllers import member
@@ -44,14 +46,13 @@ class PoolsController(base.BaseController):
 
     def __init__(self):
         super(PoolsController, self).__init__()
-        self.handler = self.handler.pool
 
     @wsme_pecan.wsexpose(pool_types.PoolRootResponse, wtypes.text,
                          [wtypes.text], ignore_extra_args=True)
     def get(self, id, fields=None):
         """Gets a pool's details."""
         context = pecan.request.context.get('octavia_context')
-        db_pool = self._get_db_pool(context.session, id)
+        db_pool = self._get_db_pool(context.session, id, show_deleted=False)
 
         self._auth_validate_action(context, db_pool.project_id,
                                    constants.RBAC_GET_ONE)
@@ -126,23 +127,48 @@ class PoolsController(base.BaseController):
             # do not give any information as to what constraint failed
             raise exceptions.InvalidOption(value='', option='')
 
-    def _send_pool_to_handler(self, session, db_pool, listener_id):
-        try:
-            LOG.info("Sending Creation of Pool %s to handler", db_pool.id)
-            self.handler.create(db_pool)
-        except Exception:
-            with excutils.save_and_reraise_exception(
-                    reraise=False), db_api.get_lock_session() as lock_session:
-                self._reset_lb_and_listener_statuses(
-                    lock_session, lb_id=db_pool.load_balancer_id,
-                    listener_ids=[listener_id] if listener_id else [])
-                # Pool now goes to ERROR
-                self.repositories.pool.update(
-                    lock_session, db_pool.id,
-                    provisioning_status=constants.ERROR)
-        db_pool = self._get_db_pool(session, db_pool.id)
-        result = self._convert_db_to_type(db_pool, pool_types.PoolResponse)
-        return pool_types.PoolRootResponse(pool=result)
+    def _is_only_specified_in_request(self, request, **kwargs):
+        request_attrs = []
+        check_attrs = kwargs['check_exist_attrs']
+        escaped_attrs = ['from_data_model',
+                         'translate_dict_keys_to_data_model', 'to_dict']
+
+        for attr in dir(request):
+            if attr.startswith('_') or attr in escaped_attrs:
+                continue
+            else:
+                request_attrs.append(attr)
+
+        for req_attr in request_attrs:
+            if (getattr(request, req_attr) and req_attr not in check_attrs):
+                return False
+        return True
+
+    def _validate_pool_request_for_udp(self, request):
+        if request.session_persistence:
+            if (request.session_persistence.type ==
+                    constants.SESSION_PERSISTENCE_SOURCE_IP and
+                    not self._is_only_specified_in_request(
+                        request.session_persistence,
+                        check_exist_attrs=['type', 'persistence_timeout',
+                                           'persistence_granularity'])):
+                raise exceptions.ValidationException(detail=_(
+                    "session_persistence %s type for UDP protocol "
+                    "only accepts: type, persistence_timeout, "
+                    "persistence_granularity.") % (
+                        constants.SESSION_PERSISTENCE_SOURCE_IP))
+            elif request.session_persistence.cookie_name:
+                raise exceptions.ValidationException(detail=_(
+                    "Cookie names are not supported for %s pools.") %
+                    constants.PROTOCOL_UDP)
+            elif request.session_persistence.type in [
+                constants.SESSION_PERSISTENCE_HTTP_COOKIE,
+                    constants.SESSION_PERSISTENCE_APP_COOKIE]:
+                raise exceptions.ValidationException(detail=_(
+                    "Session persistence of type %(type)s is not supported "
+                    "for %(protocol)s protocol pools.") % {
+                    'type': request.session_persistence.type,
+                    'protocol': constants.PROTOCOL_UDP})
 
     @wsme_pecan.wsexpose(pool_types.PoolRootResponse,
                          body=pool_types.PoolRootPOST, status_code=201)
@@ -158,15 +184,24 @@ class PoolsController(base.BaseController):
         # pool_dict:
         pool = pool_.pool
         context = pecan.request.context.get('octavia_context')
-
+        if pool.protocol == constants.PROTOCOL_UDP:
+            self._validate_pool_request_for_udp(pool)
+        else:
+            if (pool.session_persistence and (
+                    pool.session_persistence.persistence_timeout or
+                    pool.session_persistence.persistence_granularity)):
+                raise exceptions.ValidationException(detail=_(
+                    "persistence_timeout and persistence_granularity "
+                    "is only for UDP protocol pools."))
         if pool.loadbalancer_id:
-            pool.project_id = self._get_lb_project_id(context.session,
-                                                      pool.loadbalancer_id)
+            pool.project_id, provider = self._get_lb_project_id_provider(
+                context.session, pool.loadbalancer_id)
         elif pool.listener_id:
             listener = self.repositories.listener.get(
                 context.session, id=pool.listener_id)
-            pool.project_id = listener.project_id
             pool.loadbalancer_id = listener.load_balancer_id
+            pool.project_id, provider = self._get_lb_project_id_provider(
+                context.session, pool.loadbalancer_id)
         else:
             msg = _("Must provide at least one of: "
                     "loadbalancer_id, listener_id")
@@ -179,6 +214,9 @@ class PoolsController(base.BaseController):
             sp_dict = pool.session_persistence.to_dict(render_unsets=False)
             validate.check_session_persistence(sp_dict)
 
+        # Load the driver early as it also provides validation
+        driver = driver_factory.get_driver(provider)
+
         lock_session = db_api.get_session(autocommit=False)
         try:
             if self.repositories.check_quota_met(
@@ -205,13 +243,25 @@ class PoolsController(base.BaseController):
 
             db_pool = self._validate_create_pool(
                 lock_session, pool_dict, listener_id)
+
+            # Prepare the data for the driver data model
+            provider_pool = (
+                driver_utils.db_pool_to_provider_pool(db_pool))
+
+            # Dispatch to the driver
+            LOG.info("Sending create Pool %s to provider %s",
+                     db_pool.id, driver.name)
+            driver_utils.call_provider(
+                driver.name, driver.pool_create, provider_pool)
+
             lock_session.commit()
         except Exception:
             with excutils.save_and_reraise_exception():
                 lock_session.rollback()
 
-        return self._send_pool_to_handler(context.session, db_pool,
-                                          listener_id=listener_id)
+        db_pool = self._get_db_pool(context.session, db_pool.id)
+        result = self._convert_db_to_type(db_pool, pool_types.PoolResponse)
+        return pool_types.PoolRootResponse(pool=result)
 
     def _graph_create(self, session, lock_session, pool_dict):
         load_balancer_id = pool_dict['load_balancer_id']
@@ -236,6 +286,7 @@ class PoolsController(base.BaseController):
             hm['project_id'] = db_pool.project_id
             new_hm = health_monitor.HealthMonitorController()._graph_create(
                 lock_session, hm)
+            db_pool.health_monitor = new_hm
 
         # Now check quotas for members
         if members and self.repositories.check_quota_met(
@@ -253,7 +304,8 @@ class PoolsController(base.BaseController):
             new_members.append(
                 member.MembersController(db_pool.id)._graph_create(
                     lock_session, m))
-        return db_pool, new_hm, new_members
+        db_pool.members = new_members
+        return db_pool
 
     @wsme_pecan.wsexpose(pool_types.PoolRootResponse, wtypes.text,
                          body=pool_types.PoolRootPut, status_code=200)
@@ -261,35 +313,65 @@ class PoolsController(base.BaseController):
         """Updates a pool on a load balancer."""
         pool = pool_.pool
         context = pecan.request.context.get('octavia_context')
-        db_pool = self._get_db_pool(context.session, id)
+        db_pool = self._get_db_pool(context.session, id, show_deleted=False)
 
-        self._auth_validate_action(context, db_pool.project_id,
-                                   constants.RBAC_PUT)
+        project_id, provider = self._get_lb_project_id_provider(
+            context.session, db_pool.load_balancer_id)
+
+        if (pool.session_persistence and
+                not pool.session_persistence.type and
+                db_pool.session_persistence and
+                db_pool.session_persistence.type):
+            pool.session_persistence.type = db_pool.session_persistence.type
+        self._auth_validate_action(context, project_id, constants.RBAC_PUT)
+        if db_pool.protocol == constants.PROTOCOL_UDP:
+            self._validate_pool_request_for_udp(pool)
+        else:
+            if (pool.session_persistence and (
+                    pool.session_persistence.persistence_timeout or
+                    pool.session_persistence.persistence_granularity)):
+                raise exceptions.ValidationException(detail=_(
+                    "persistence_timeout and persistence_granularity "
+                    "is only for UDP protocol pools."))
 
         if pool.session_persistence:
             sp_dict = pool.session_persistence.to_dict(render_unsets=False)
             validate.check_session_persistence(sp_dict)
 
-        self._test_lb_and_listener_statuses(
-            context.session, lb_id=db_pool.load_balancer_id,
-            listener_ids=self._get_affected_listener_ids(db_pool))
-        self.repositories.pool.update(
-            context.session, db_pool.id,
-            provisioning_status=constants.PENDING_UPDATE)
+        # Load the driver early as it also provides validation
+        driver = driver_factory.get_driver(provider)
 
-        try:
-            LOG.info("Sending Update of Pool %s to handler", id)
-            self.handler.update(db_pool, pool)
-        except Exception:
-            with excutils.save_and_reraise_exception(
-                    reraise=False), db_api.get_lock_session() as lock_session:
-                self._reset_lb_and_listener_statuses(
-                    lock_session, lb_id=db_pool.load_balancer_id,
-                    listener_ids=self._get_affected_listener_ids(db_pool))
-                # Pool now goes to ERROR
-                self.repositories.pool.update(
-                    lock_session, db_pool.id,
-                    provisioning_status=constants.ERROR)
+        with db_api.get_lock_session() as lock_session:
+            self._test_lb_and_listener_statuses(
+                context.session, lb_id=db_pool.load_balancer_id,
+                listener_ids=self._get_affected_listener_ids(db_pool))
+
+            # Prepare the data for the driver data model
+            pool_dict = pool.to_dict(render_unsets=False)
+            pool_dict['id'] = id
+            provider_pool_dict = (
+                driver_utils.pool_dict_to_provider_dict(pool_dict))
+
+            # Also prepare the baseline object data
+            old_provider_pool = driver_utils.db_pool_to_provider_pool(
+                db_pool)
+
+            # Dispatch to the driver
+            LOG.info("Sending update Pool %s to provider %s", id, driver.name)
+            driver_utils.call_provider(
+                driver.name, driver.pool_update,
+                old_provider_pool,
+                driver_dm.Pool.from_dict(provider_pool_dict))
+
+            # Update the database to reflect what the driver just accepted
+            pool.provisioning_status = constants.PENDING_UPDATE
+            db_pool_dict = pool.to_dict(render_unsets=False)
+            self.repositories.update_pool_and_sp(lock_session, id,
+                                                 db_pool_dict)
+
+        # Force SQL alchemy to query the DB, otherwise we get inconsistent
+        # results
+        context.session.expire_all()
         db_pool = self._get_db_pool(context.session, id)
         result = self._convert_db_to_type(db_pool, pool_types.PoolResponse)
         return pool_types.PoolRootResponse(pool=result)
@@ -298,37 +380,32 @@ class PoolsController(base.BaseController):
     def delete(self, id):
         """Deletes a pool from a load balancer."""
         context = pecan.request.context.get('octavia_context')
-        db_pool = self._get_db_pool(context.session, id)
-        if len(db_pool.l7policies) > 0:
+        db_pool = self._get_db_pool(context.session, id, show_deleted=False)
+        if db_pool.l7policies:
             raise exceptions.PoolInUseByL7Policy(
                 id=db_pool.id, l7policy_id=db_pool.l7policies[0].id)
 
-        self._auth_validate_action(context, db_pool.project_id,
-                                   constants.RBAC_DELETE)
+        project_id, provider = self._get_lb_project_id_provider(
+            context.session, db_pool.load_balancer_id)
 
-        if db_pool.provisioning_status == constants.DELETED:
-            return
+        self._auth_validate_action(context, project_id, constants.RBAC_DELETE)
 
-        self._test_lb_and_listener_statuses(
-            context.session, lb_id=db_pool.load_balancer_id,
-            listener_ids=self._get_affected_listener_ids(db_pool))
-        self.repositories.pool.update(
-            context.session, db_pool.id,
-            provisioning_status=constants.PENDING_DELETE)
+        # Load the driver early as it also provides validation
+        driver = driver_factory.get_driver(provider)
 
-        try:
-            LOG.info("Sending Deletion of Pool %s to handler", db_pool.id)
-            self.handler.delete(db_pool)
-        except Exception:
-            with excutils.save_and_reraise_exception(
-                    reraise=False), db_api.get_lock_session() as lock_session:
-                self._reset_lb_and_listener_statuses(
-                    lock_session, lb_id=db_pool.load_balancer_id,
-                    listener_ids=self._get_affected_listener_ids(db_pool))
-                # Pool now goes to ERROR
-                self.repositories.pool.update(
-                    lock_session, db_pool.id,
-                    provisioning_status=constants.ERROR)
+        with db_api.get_lock_session() as lock_session:
+            self._test_lb_and_listener_statuses(
+                lock_session, lb_id=db_pool.load_balancer_id,
+                listener_ids=self._get_affected_listener_ids(db_pool))
+            self.repositories.pool.update(
+                lock_session, db_pool.id,
+                provisioning_status=constants.PENDING_DELETE)
+
+            LOG.info("Sending delete Pool %s to provider %s", id, driver.name)
+            provider_pool = (
+                driver_utils.db_pool_to_provider_pool(db_pool))
+            driver_utils.call_provider(driver.name, driver.pool_delete,
+                                       provider_pool)
 
     @pecan.expose()
     def _lookup(self, pool_id, *remainder):
@@ -338,7 +415,7 @@ class PoolsController(base.BaseController):
         which controller, if any, should control be passed.
         """
         context = pecan.request.context.get('octavia_context')
-        if pool_id and len(remainder) and remainder[0] == 'members':
+        if pool_id and remainder and remainder[0] == 'members':
             remainder = remainder[1:]
             db_pool = self.repositories.pool.get(context.session, id=pool_id)
             if not db_pool:
@@ -347,5 +424,5 @@ class PoolsController(base.BaseController):
                                           id=pool_id)
             if remainder:
                 return member.MemberController(pool_id=db_pool.id), remainder
-            else:
-                return member.MembersController(pool_id=db_pool.id), remainder
+            return member.MembersController(pool_id=db_pool.id), remainder
+        return None
