@@ -31,9 +31,11 @@ HEALTH_MONITOR_TCP = 'TCP'
 HEALTH_MONITOR_HTTP = 'HTTP'
 HEALTH_MONITOR_HTTPS = 'HTTPS'
 HEALTH_MONITOR_TLS_HELLO = 'TLS-HELLO'
+HEALTH_MONITOR_UDP_CONNECT = 'UDP-CONNECT'
 SUPPORTED_HEALTH_MONITOR_TYPES = (HEALTH_MONITOR_HTTP, HEALTH_MONITOR_HTTPS,
                                   HEALTH_MONITOR_PING, HEALTH_MONITOR_TCP,
-                                  HEALTH_MONITOR_TLS_HELLO)
+                                  HEALTH_MONITOR_TLS_HELLO,
+                                  HEALTH_MONITOR_UDP_CONNECT)
 HEALTH_MONITOR_HTTP_METHOD_GET = 'GET'
 HEALTH_MONITOR_HTTP_METHOD_HEAD = 'HEAD'
 HEALTH_MONITOR_HTTP_METHOD_POST = 'POST'
@@ -52,23 +54,31 @@ SUPPORTED_HEALTH_MONITOR_HTTP_METHODS = (
     HEALTH_MONITOR_HTTP_METHOD_PATCH)
 HEALTH_MONITOR_DEFAULT_EXPECTED_CODES = '200'
 HEALTH_MONITOR_DEFAULT_URL_PATH = '/'
+TYPE = 'type'
+URL_PATH = 'url_path'
+HTTP_METHOD = 'http_method'
+EXPECTED_CODES = 'expected_codes'
+DELAY = 'delay'
+TIMEOUT = 'timeout'
+MAX_RETRIES = 'max_retries'
+RISE_THRESHOLD = 'rise_threshold'
 
 UPDATE_STATS = 'UPDATE_STATS'
 UPDATE_HEALTH = 'UPDATE_HEALTH'
 
 PROTOCOL_TCP = 'TCP'
+PROTOCOL_UDP = 'UDP'
 PROTOCOL_HTTP = 'HTTP'
 PROTOCOL_HTTPS = 'HTTPS'
 PROTOCOL_TERMINATED_HTTPS = 'TERMINATED_HTTPS'
 PROTOCOL_PROXY = 'PROXY'
 SUPPORTED_PROTOCOLS = (PROTOCOL_TCP, PROTOCOL_HTTPS, PROTOCOL_HTTP,
-                       PROTOCOL_TERMINATED_HTTPS, PROTOCOL_PROXY)
+                       PROTOCOL_TERMINATED_HTTPS, PROTOCOL_PROXY, PROTOCOL_UDP)
 
 # API Integer Ranges
 MIN_PORT_NUMBER = 1
 MAX_PORT_NUMBER = 65535
 
-DEFAULT_CONNECTION_LIMIT = -1
 MIN_CONNECTION_LIMIT = -1
 
 MIN_WEIGHT = 0
@@ -77,6 +87,15 @@ MAX_WEIGHT = 256
 MIN_HM_RETRIES = 1
 MAX_HM_RETRIES = 10
 
+# 1 year:     y     d    h    m    ms
+MAX_TIMEOUT = 365 * 24 * 60 * 60 * 1000
+MIN_TIMEOUT = 0
+
+DEFAULT_TIMEOUT_CLIENT_DATA = 50000
+DEFAULT_TIMEOUT_MEMBER_CONNECT = 5000
+DEFAULT_TIMEOUT_MEMBER_DATA = 50000
+DEFAULT_TIMEOUT_TCP_INSPECT = 0
+
 # Note: The database Amphora table has a foreign key constraint against
 #       the provisioning_status table
 # Amphora has been allocated to a load balancer
@@ -184,14 +203,19 @@ FAILOVER_AMPHORA_ID = 'failover_amphora_id'
 DELTA = 'delta'
 DELTAS = 'deltas'
 HEALTH_MON = 'health_mon'
+HEALTH_MONITOR = 'health_monitor'
 LISTENER = 'listener'
 LISTENERS = 'listeners'
+LISTENER_ID = 'listener_id'
 LOADBALANCER = 'loadbalancer'
+LOADBALANCERS = 'loadbalancers'
 LOADBALANCER_ID = 'loadbalancer_id'
+LOAD_BALANCER_ID = 'load_balancer_id'
 SERVER_GROUP_ID = 'server_group_id'
 ANTI_AFFINITY = 'anti-affinity'
 SOFT_ANTI_AFFINITY = 'soft-anti-affinity'
 MEMBER = 'member'
+MEMBERS = 'members'
 MEMBER_ID = 'member_id'
 COMPUTE_ID = 'compute_id'
 COMPUTE_OBJ = 'compute_obj'
@@ -200,6 +224,7 @@ AMPS_DATA = 'amps_data'
 NICS = 'nics'
 VIP = 'vip'
 POOL = 'pool'
+POOLS = 'pools'
 POOL_CHILD_COUNT = 'pool_child_count'
 POOL_ID = 'pool_id'
 L7POLICY = 'l7policy'
@@ -213,8 +238,11 @@ ADDED_PORTS = 'added_ports'
 PORTS = 'ports'
 MEMBER_PORTS = 'member_ports'
 LOADBALANCER_TOPOLOGY = 'topology'
+HEALTHMONITORS = 'healthmonitors'
 HEALTH_MONITOR_ID = 'health_monitor_id'
+L7POLICIES = 'l7policies'
 L7POLICY_ID = 'l7policy_id'
+L7RULES = 'l7rules'
 L7RULE_ID = 'l7rule_id'
 LOAD_BALANCER_UPDATES = 'load_balancer_updates'
 LISTENER_UPDATES = 'listener_updates'
@@ -411,6 +439,7 @@ KEEPALIVED_JINJA2_UPSTART = 'keepalived.upstart.j2'
 KEEPALIVED_JINJA2_SYSTEMD = 'keepalived.systemd.j2'
 KEEPALIVED_JINJA2_SYSVINIT = 'keepalived.sysvinit.j2'
 CHECK_SCRIPT_CONF = 'keepalived_check_script.conf.j2'
+KEEPALIVED_CHECK_SCRIPT = 'keepalived_lvs_check_script.sh.j2'
 
 PLUGGED_INTERFACES = '/var/lib/octavia/plugged_interfaces'
 HAPROXY_USER_GROUP_CFG = '/var/lib/octavia/haproxy-default-user-group.conf'
@@ -418,7 +447,8 @@ AMPHORA_NAMESPACE = 'amphora-haproxy'
 
 # List of HTTP headers which are supported for insertion
 SUPPORTED_HTTP_HEADERS = ['X-Forwarded-For',
-                          'X-Forwarded-Port']
+                          'X-Forwarded-Port',
+                          'X-Forwarded-Proto']
 
 FLOW_DOC_TITLES = {'AmphoraFlows': 'Amphora Flows',
                    'LoadBalancerFlows': 'Load Balancer Flows',
@@ -454,6 +484,10 @@ KEEPALIVED_SYSTEMD = 'octavia-keepalived.service'
 KEEPALIVED_SYSVINIT = 'octavia-keepalived'
 KEEPALIVED_UPSTART = 'octavia-keepalived.conf'
 
+KEEPALIVED_SYSTEMD_PREFIX = 'octavia-keepalivedlvs-%s.service'
+KEEPALIVED_SYSVINIT_PREFIX = 'octavia-keepalivedlvs-%s'
+KEEPALIVED_UPSTART_PREFIX = 'octavia-keepalivedlvs-%s.conf'
+
 # Authentication
 KEYSTONE = 'keystone'
 NOAUTH = 'noauth'
@@ -493,6 +527,7 @@ RBAC_L7POLICY = '{}:l7policy:'.format(LOADBALANCER_API)
 RBAC_L7RULE = '{}:l7rule:'.format(LOADBALANCER_API)
 RBAC_QUOTA = '{}:quota:'.format(LOADBALANCER_API)
 RBAC_AMPHORA = '{}:amphora:'.format(LOADBALANCER_API)
+RBAC_PROVIDER = '{}:provider:'.format(LOADBALANCER_API)
 RBAC_POST = 'post'
 RBAC_PUT = 'put'
 RBAC_PUT_FAILOVER = 'put_failover'
@@ -507,7 +542,6 @@ RBAC_GET_STATUS = 'get_status'
 # PROVIDERS
 # TODO(johnsom) When providers are implemented, this should be removed.
 OCTAVIA = 'octavia'
-SUPPORTED_PROVIDERS = OCTAVIA,
 
 # FLAVORS
 # TODO(johnsom) When flavors are implemented, this should be removed.
